@@ -41,7 +41,13 @@ inline_text <- function(x, ...) {
 #' inline_text(t2, variable = grade, column = "p.value")
 inline_text.tbl_summary <-
   function(x, variable, column = NULL, level = NULL, pattern = NULL,
-           pvalue_fun = function(x) style_pvalue(x, prepend_p = TRUE), ...) {
+           pvalue_fun = NULL, ...) {
+    # setting defaults ---------------------------------------------------------
+    pvalue_fun <-
+      pvalue_fun %||%
+      get_theme_element("pkgwide-fn:prependpvalue_fun") %||%
+      (function(x) style_pvalue(x, prepend_p = TRUE))
+
     # create rlang::enquo() inputs ---------------------------------------------
     variable <- rlang::enquo(variable)
     column <- rlang::enquo(column)
@@ -194,7 +200,13 @@ inline_text.tbl_regression <-
   function(x, variable, level = NULL,
            pattern = "{estimate} ({conf.level*100}% CI {conf.low}, {conf.high}; {p.value})",
            estimate_fun = x$fmt_fun$estimate,
-           pvalue_fun = function(x) style_pvalue(x, prepend_p = TRUE), ...) {
+           pvalue_fun = NULL, ...) {
+    # setting defaults ---------------------------------------------------------
+    pvalue_fun <-
+      pvalue_fun %||%
+      get_theme_element("pkgwide-fn:prependpvalue_fun") %||%
+      (function(x) style_pvalue(x, prepend_p = TRUE))
+
     # setting quos -------------------------------------------------------------
     variable <- rlang::enquo(variable)
     level <- rlang::enquo(level)
@@ -384,8 +396,6 @@ inline_text.tbl_survival <-
         mutate(fixed_var = prob)
     }
 
-
-
     # select strata ------------------------------------------------------------
     # if multiple strata exist in tbl_survival, grab rows matching specified strata
     if ("strata" %in% names(x$table_long)) {
@@ -488,8 +498,15 @@ inline_text.tbl_survival <-
 #' inline_text(tbl2, prob = 0.5)
 inline_text.tbl_survfit <-
   function(x, time = NULL, prob = NULL, level = NULL,
-           estimate_fun = NULL,
-           pvalue_fun = function(x) style_pvalue(x, prepend_p = TRUE), ...) {
+           estimate_fun = NULL, pvalue_fun = NULL, ...) {
+    # setting defaults ---------------------------------------------------------
+    pvalue_fun <-
+      pvalue_fun %||%
+      get_theme_element("pkgwide-fn:prependpvalue_fun") %||%
+      (function(x) style_pvalue(x, prepend_p = TRUE))
+
+    if (is.null(estimate_fun)) estimate_fun <- x$inputs$estimate_fun
+
     # checking inputs ----------------------------------------------------------
     if (c(is.null(time), is.null(prob)) %>% sum() != 1) {
       stop("One and only one of `time=` and `prob=` must be specified.", call. = FALSE)
@@ -503,9 +520,6 @@ inline_text.tbl_survfit <-
       stop("`time=` was specified, but `x` does not contain survival time estimates.", call. = FALSE)
     }
 
-    # estimate_fun -------------------------------------------------------------
-    if (is.null(estimate_fun)) estimate_fun <- x$inputs$estimate_fun
-
     # selecting level ----------------------------------------------------------
     level <- rlang::enquo(level)
 
@@ -581,10 +595,8 @@ inline_text.tbl_survfit <-
 #' @param x a `tbl_cross` object
 #' @param row_level Level of the row variable to display.
 #' Can also specify the 'Unknown' row. Default is `NULL`
-#' @param col_level Level of the column variable to display.
+#' @param col_level Level of the column variable to display. Default is `NULL`
 #' Can also specify "`p.value`" for the p-value and "`stat_0`" for Total column.
-#' @param pattern String indicating the statistics to return.
-#' Uses [glue::glue] formatting. Default is pattern shown in `tbl_cross()` output
 #' @inheritParams inline_text.tbl_summary
 #'
 #' @return A string reporting results from a gtsummary table
@@ -600,8 +612,19 @@ inline_text.tbl_survfit <-
 #' inline_text(tbl_cross, col_level = "p.value")
 
 inline_text.tbl_cross <-
-  function(x, col_level, row_level = NULL, pattern = NULL,
-           pvalue_fun = function(x) style_pvalue(x, prepend_p = TRUE), ...) {
+  function(x, col_level = NULL, row_level = NULL,
+           pvalue_fun = NULL, ...) {
+
+    # check arguments ----------------------------------------------------------
+    if (is.null(col_level) | (is.null(row_level) & !identical("p.value", col_level))) {
+      stop("Please specify both `col_level=` and `row_level=` arguments")
+    }
+
+    # setting defaults ---------------------------------------------------------
+    pvalue_fun <-
+      pvalue_fun %||%
+      get_theme_element("pkgwide-fn:prependpvalue_fun") %||%
+      (function(x) style_pvalue(x, prepend_p = TRUE))
 
     # row_level ----------------------------------------------------------------
     # converting row_level to a string
@@ -654,8 +677,7 @@ inline_text.tbl_cross <-
     # evaluating inline_text for tbl_summary -----------------------------------
     expr(
       inline_text.tbl_summary(x, variable = !!variable, level = !!row_level,
-                              column = {{ col_level }}, pattern = !!pattern,
-                              pvalue_fun = !!pvalue_fun)
+                              column = {{ col_level }}, pvalue_fun = !!pvalue_fun)
     ) %>%
       eval()
   }
