@@ -18,6 +18,15 @@ knitr::knit_print
 #' @export
 dplyr::vars
 
+#' @importFrom dplyr select
+#' @export
+dplyr::select
+
+# huxtable ---------------------------------------------------------------------
+#' @export
+#' @importFrom huxtable as_huxtable
+huxtable::as_huxtable
+
 # tidyselect -------------------------------------------------------------------
 #' @importFrom tidyselect starts_with
 #' @export
