@@ -32,6 +32,7 @@
 #' fit1 <- survfit(Surv(ttdeath, death) ~ trt, trial)
 #' fit2 <- survfit(Surv(ttdeath, death) ~ 1, trial)
 #'
+#' # Example 1 ----------------------------------
 #' tbl_survfit_ex1 <- tbl_survfit(
 #'   fit1,
 #'   times = c(12, 24),
@@ -39,6 +40,7 @@
 #'   label_header = "**{time} Month**"
 #' )
 #'
+#' # Example 2 ----------------------------------
 #' tbl_survfit_ex2 <- tbl_survfit(
 #'   fit2,
 #'   probs = 0.5,
@@ -57,6 +59,11 @@ tbl_survfit <- function(x, times = NULL, probs = NULL,
                         statistic = "{estimate} ({conf.low}, {conf.high})",
                         label = NULL, label_header = NULL, estimate_fun = NULL,
                         missing = "--", conf.level = 0.95, failure = FALSE) {
+  # setting defaults -----------------------------------------------------------
+  statistic <-
+    statistic %||%
+    get_theme_element("tbl_survfit-arg:statistic") %||%
+    "{estimate} ({conf.low}, {conf.high})"
 
   # input checks ---------------------------------------------------------------
   if (c(is.null(times), is.null(probs)) %>% sum() != 1) {
