@@ -10,8 +10,8 @@
 #' @keywords internal
 #' @author Daniel D. Sjoberg
 
-assign_test <- function(data, var, var_summary_type, by_var, test, group) {
-  map2_chr(
+assign_test <- function(data, var, var_summary_type, by_var, test, group, env) {
+  map2(
     var, var_summary_type,
     ~ assign_test_one(
       data = data,
@@ -19,44 +19,111 @@ assign_test <- function(data, var, var_summary_type, by_var, test, group) {
       var_summary_type = .y,
       by_var = by_var,
       test = test,
-      group = group
+      group = group,
+      env = env
     )
   )
 }
 
-assign_test_one <- function(data, var, var_summary_type, by_var, test, group) {
-  # if user specifed test to be performed, do that test.
-  if (!is.null(test[[var]])) {
-    return(test[[var]])
+# test_match_to_fn -------------------------------------------------------------
+# little function to return the function from the shortcut name,
+# this is a helper function for assign_test_one()
+test_match_to_fn <- function(x, env) {
+  if (is.null(x)) return(NULL)
+
+  # lookup table
+  df_lookup <-
+    tibble::tribble(
+      ~fun_chr, ~fun_base_r, ~fun_add_p,
+      "t.test", stats::t.test, add_p_test_t.test,
+      "aov", stats::aov, add_p_test_aov,
+      "kruskal.test", stats::kruskal.test, add_p_test_kruskal.test,
+      "wilcox.test", stats::wilcox.test, add_p_test_wilcox.test,
+      "chisq.test", stats::chisq.test, add_p_test_chisq.test,
+      "chisq.test.no.correct", NULL, add_p_test_chisq.test.no.correct,
+      "fisher.test", stats::fisher.test, add_p_test_fisher.test,
+      "lme4", NULL, add_p_test_lme4
+    )
+
+  # if string was passed, match `fun_chr`
+  if (rlang::is_string(x) && x %in% df_lookup$fun_chr) {
+      return(df_lookup$fun_add_p[df_lookup$fun_chr %in% x] %>% pluck(1))
+  }
+
+  # if fn was passed, match `fun_base_r`
+  if (rlang::is_function(x)) {
+    lgl <- map_lgl(df_lookup$fun_base_r, function(fn) identical(fn, x))
+    if (any(lgl))
+      return(df_lookup$fun_add_p[lgl] %>% pluck(1))
+  }
+
+  # if the input is a function, return it
+  if (rlang::is_function(x)) return(x)
+
+  # if the user passed a string, return the function that is the string
+  if (rlang::is_string(x))
+    return(rlang::parse_expr(x) %>% rlang::eval_tidy(env = env))
+
+  # if not a match, return NULL
+  return(NULL)
+}
+
+# assign_test_one() ------------------------------------------------------------
+assign_test_one <- function(data, var, var_summary_type, by_var, test, group, env) {
+  # if user specifed test to be performed, do that test. -----------------------
+  # matching an internal test by name or base R function match
+  # or returning the appropriate test based on what is passed
+  test_func <- test_match_to_fn(test[[var]], env = env)
+  if (!is.null(test_func)) return(test_func)
+
+  # if no test supplied, setting defaults --------------------------------------
+  # if by var hs 3 or more levels, return error...no default test.
+  if (!is.null(group) && length(unique(data[[by_var]])) > 2) {
+    stop("There is no default test for correlated data when `by=` variable has >2 levels.", call. = FALSE)
   }
 
   # if group variable supplied, fit a random effects model
   if (!is.null(group) & length(unique(data[[by_var]])) == 2) {
     if (var_summary_type == "continuous") {
-      return(getOption("gtsummary.add_p.test.continuous.group_by2", default = "lme4"))
+      test_func <-
+        get_theme_element("add_p.tbl_summary-attr:test.continuous.group_by2") %||%
+        getOption("gtsummary.add_p.test.continuous.group_by2", default = "lme4") %>%
+        test_match_to_fn()
+      return(test_func)
     }
     if (var_summary_type %in% c("categorical", "dichotomous")) {
-      return(getOption("gtsummary.add_p.test.categorical.group_by2", default = "lme4"))
+      test_func <-
+        get_theme_element("add_p.tbl_summary-attr:test.categorical.group_by2") %||%
+        getOption("gtsummary.add_p.test.categorical.group_by2", default = "lme4") %>%
+        test_match_to_fn()
+      return(test_func)
     }
   }
 
-  # unless by_var has >2 levels, then return NA with a message
-  if (!is.null(group) & length(unique(data[[by_var]])) > 2) {
-    message(paste0(var, ": P-value calculation for clustered data when by variables have >2 levels is not currently supported"))
-    return(NA_character_)
-  }
-
   # for continuous data, default to non-parametric tests
   if (var_summary_type == "continuous" & length(unique(data[[by_var]])) == 2) {
-    return(getOption("gtsummary.add_p.test.continuous_by2", default = "wilcox.test"))
+    test_func <-
+      get_theme_element("add_p.tbl_summary-attr:test.continuous_by2") %||%
+      getOption("gtsummary.add_p.test.continuous_by2", default = "wilcox.test") %>%
+      test_match_to_fn()
+    return(test_func)
   }
   if (var_summary_type == "continuous") {
-    return(getOption("gtsummary.add_p.test.continuous", default = "kruskal.test"))
+    test_func <-
+      get_theme_element("add_p.tbl_summary-attr:test.continuous") %||%
+      getOption("gtsummary.add_p.test.continuous", default = "kruskal.test") %>%
+      test_match_to_fn()
+    return(test_func)
   }
 
   # if all obs are missing, assigning chisq
-  if (length(data[[var]]) == sum(is.na(data[[var]])))
-    return(getOption("gtsummary.add_p.test.categorical", default = "chisq.test"))
+  if (length(data[[var]]) == sum(is.na(data[[var]]))) {
+    test_func <-
+      get_theme_element("add_p.tbl_summary-attr:test.categorical") %||%
+      getOption("gtsummary.add_p.test.categorical", default = "chisq.test") %>%
+      test_match_to_fn()
+    return(test_func)
+  }
 
   # calculate expected counts
   min_exp <-
@@ -73,9 +140,17 @@ assign_test_one <- function(data, var, var_summary_type, by_var, test, group) {
 
   # if expected counts >= 5 for all cells, chisq, otherwise Fishers exact
   if (min_exp >= 5) {
-    return(getOption("gtsummary.add_p.test.categorical", default = "chisq.test"))
+    test_func <-
+      get_theme_element("add_p.tbl_summary-attr:test.categorical") %||%
+      getOption("gtsummary.add_p.test.categorical", default = "chisq.test") %>%
+      test_match_to_fn()
+    return(test_func)
   }
-  return(getOption("gtsummary.add_p.test.categorical.low_count", default = "fisher.test"))
+  test_func <-
+    get_theme_element("add_p.tbl_summary-attr:test.categorical.low_count") %||%
+    getOption("gtsummary.add_p.test.categorical.low_count", default = "fisher.test") %>%
+    test_match_to_fn()
+  return(test_func)
 }
 
 
@@ -107,7 +182,8 @@ add_p_test_wilcox.test <- function(data, variable, by, ...) {
   if (length(unique(data[[by]])) > 2) {
     stop("Wilcoxon rank-sum test cannot be calculated with more than 2 groups")
   }
-  result$p <- stats::kruskal.test(data[[variable]], as.factor(data[[by]]))$p.value
+  result$p <- stats::wilcox.test(data[[variable]],
+                                 as.numeric(as.factor(data[[by]])))$p.value
   result$test <- "Wilcoxon rank-sum test"
   result
 }
@@ -183,22 +259,9 @@ add_p_test_safe <- function(data, variable, by, group, test, include = NULL, typ
   tryCatch(
     withCallingHandlers(
       {
-        test_func <- switch(
-          test,
-          t.test = add_p_test_t.test,
-          aov = add_p_test_aov,
-          kruskal.test = add_p_test_kruskal.test,
-          wilcox.test = add_p_test_wilcox.test,
-          chisq.test = add_p_test_chisq.test,
-          chisq.test.no.correct = add_p_test_chisq.test.no.correct,
-          fisher.test = add_p_test_fisher.test,
-          lme4 = add_p_test_lme4
-        ) %||% # if not an internal test, then resolving to function name supplied
-          test
-
         # initializing to NA
         pval <- NA_real_
-        pval <- do.call(test_func, list(
+        pval <- do.call(test, list(
           data = data, variable = variable,
           by = by, group = group, test = test,
           type = type
@@ -207,16 +270,15 @@ add_p_test_safe <- function(data, variable, by, group, test, include = NULL, typ
       # printing warning and errors as message
       warning = function(w) {
         message(glue(
-          "Warning in 'add_p()' for variable '{variable}' ",
-          "and test '{test}':\n ", as.character(w)
+          "Warning in 'add_p()' for variable '{variable}':\n ", as.character(w)
         ))
         invokeRestart("muffleWarning")
       }
     ),
     error = function(e) {
       message(glue(
-        "There was an error in 'add_p()' for variable '{variable}' ",
-        "and test '{test}', p-value omitted:\n", as.character(e)
+        "There was an error in 'add_p()' for variable '{variable}', ",
+        "p-value omitted:\n", as.character(e)
       ))
       return(NULL)
     }
