@@ -15,8 +15,7 @@ test_that("expect error with use in tbl_summary() but NO add_p()", {
     tbl_summary(mtcars, by = am)
 
   expect_error(bold_p(table1_without_comp),
-    "Before p-values are bolded, run add_p() to calculate the p-values",
-    fixed = TRUE
+    "*",
   )
 })
 
@@ -39,8 +38,7 @@ test_that("expect error with q=TRUE and add_q() NOT USED in tbl_summary", {
     add_p()
 
   expect_error(bold_p(table1_comp_without_q, q = TRUE),
-    "Before q-values are bolded, run add_q() to calculate the q-values",
-    fixed = TRUE
+    "*",
   )
 })
 
@@ -61,8 +59,8 @@ test_that("no errors/warnings with standard use in tbl_uvregression()", {
       y = age
     )
 
-  expect_error(bold_p(fmt_uni_reg, p = 0.3), NA)
-  expect_warning(bold_p(fmt_uni_reg, p = 0.3), NA)
+  expect_error(bold_p(fmt_uni_reg, t = 0.3), NA)
+  expect_warning(bold_p(fmt_uni_reg, t = 0.3), NA)
 })
 
 
@@ -74,6 +72,6 @@ test_that("no errors/warnings with use in tbl_uvregression() with add_global_p()
     ) %>%
     add_global_p()
 
-  expect_error(bold_p(fmt_uni_reg_global_p, p = 0.3), NA)
-  expect_warning(bold_p(fmt_uni_reg_global_p, p = 0.3), NA)
+  expect_error(bold_p(fmt_uni_reg_global_p, t = 0.3), NA)
+  expect_warning(bold_p(fmt_uni_reg_global_p, t = 0.3), NA)
 })
